@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2015 by Dominique Dumont.
+# This software is Copyright (c) 2007-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -128,19 +128,21 @@
         'description' => [
             element => "Specify the elements names of this configuration class.",
             include => "Include the element description of another class into this class.",
-            include_after => "insert the included elements after a specific element",
+            include_after => "insert the included elements after a specific element. "
+            . "By default, included elements are placed before all other elements.",
             include_backend => "Include the read/write specification of another class into this class.",
-            class_description => "Explain the purpose of this configuration class. This description will be re-used to generate the documentation of your configuration class. You can use pod markup to format your description. See L<perlpod> for details.",
-            read_config => "Specify the Perl class(es) and function(s) used to read configuration data. The specified function will be tried in sequence to get configuration data. ",
+            class_description => "Explain the purpose of this configuration class. This description is re-used to generate the documentation of your configuration class. You can use pod markup to format your description. See L<perlpod> for details.",
+            read_config => "Specify the Perl class(es) and function(s) used to read configuration data. The specified functions are tried in sequence to get configuration data. ",
             write_config => "Specify the Perl class and function used to write configuration data.",
-            generated_by => "When set, this class was generated by some program. You should not edit it as your modification may be clobbered later on",
-            accept => "Specifies names of the elements this configuration class will accept as valid. "
-                ."The key of the hash is a regular expression that will be tested against 
-           candidate parameters. When the parameter matches the regular expression, 
+            generated_by => "When set, this class was generated by some program. You should not edit "
+                ."this class as your modifications may be clobbered later on when the class is regenerated.",
+            accept => "Specifies names of the elements this configuration class accepts as valid. "
+                ."The key of the hash is a regular expression that are be tested against
+           candidate parameters. When the parameter matches the regular expression,
            a new parameter is created in the model using the description provided
-           in the value of this hash key. Note that the regexp must match the whole 
-           candidate parameter name. I.e. the specified regexp will be eval\'ed 
-           with a leading ^ and a trailing \$."
+           in the value of this hash key. Note that the regexp must match the whole name
+           of the potential parameter. I.e. the specified regexp is eval\'ed
+           with a leading C<^> and a trailing C<\$>."
         ],
     ],
 
@@ -174,7 +176,10 @@
                 description => 'specify the configuration file name. This parameter may '
                     .'not be applicable depending on your application. It may also be '
                     .'hardcoded in a custom backend. If not specified, the instance name '
-                    .'will be used as base name for your configuration file.',
+                    .'is used as base name for your configuration file. The configuration file name'
+                    .'can be specified with &index keyword when a backend is associated to a node '
+                    .'contained in a hash. See '
+                    .'L<backend specifications|http://search.cpan.org/dist/Config-Model/lib/Config/Model/BackendMgr.pm#Backend_specification>.'
             },
         ]
     ],
@@ -198,20 +203,21 @@
                 type         => 'leaf',
                 class        => 'Config::Model::Itself::BackendDetector',
                 value_type   => 'enum',
-                choice       => [qw/cds_file perl_file ini_file custom/],
+                choice       => [qw/cds_file perl_file custom/],
+                replace   => {
+                    perl => 'perl_file',
+                    ini  => 'IniFile',
+                    ini_file  => 'IniFile',
+                    cds  => 'cds_file',
+                },
                 migrate_from => {
                     formula   => '$old',
                     variables => { old => '- syntax' },
-                    replace   => {
-                        perl => 'perl_file',
-                        ini  => 'ini_file',
-                        cds  => 'cds_file',
-                    },
                 },
                 description => 'specifies the backend to store permanently configuration data.',
                 help => {
                     cds_file => "file with config data string. This is Config::Model own serialisation format, designed to be compact and readable. Configuration filename is made with instance name",
-                    ini_file =>
+                    IniFile =>
 "Ini file format. Beware that the structure of your model must match the limitations of the INI file format, i.e only a 2 levels hierarchy. Configuration filename is made with instance name",
                     perl_file =>
 "file with a perl data structure. Configuration filename is made with instance name",
@@ -220,6 +226,14 @@
                }
             },
 
+            file_mode => {
+                type       => 'leaf',
+                value_type => 'uniline',
+                level      => 'normal',
+                summary     => 'configuration file mode',
+                description => 'specify the configuration file mode. C<file_mode> parameter can be used to set the '
+                    . 'mode of the written file. C<file_mode> value can be in any form suppported by L<Path::Tiny/chmod>.'
+            },
 
             default_layer => {
                 type => 'node',
@@ -250,11 +264,11 @@
                 type       => 'leaf',
                 value_type => 'uniline',
                 level      => 'hidden',
-                description => 'Specify element hash name that will contain all INI classes. '
+                description => 'Specify element hash name that contains all INI classes. '
                     .'See L<Config::Model::Backend::IniFile/"Arbitrary class name">',
                 warp => {
                     follow => '- backend',
-                    rules  => [ ini_file => { level => 'normal', } ],
+                    rules  => [ IniFile => { level => 'normal', } ],
                 }
             },
 
@@ -262,37 +276,36 @@
                 type       => 'hash',
                 level      => 'hidden',
                 index_type => 'string',
-                description => 'Specify element name that will contain one INI class. E.g. to store '
+                description => 'Specify element name that contains one INI class. E.g. to store '
                      .'INI class [foo] in element Foo, specify { foo => "Foo" } ',
                 warp => {
                     follow => '- backend',
-                    rules  => [ ini_file => { level => 'normal', } ],
+                    rules  => [ IniFile => { level => 'normal', } ],
                 },
-                cargo => { 
+                cargo => {
                     type => 'leaf',
                     value_type => 'uniline',
                 },
             },
 
-            'split_list_value' => {
+            ['split_list_value','split_check_list_value'] => {
                 type       => 'leaf',
                 value_type => 'uniline',
                 level      => 'hidden',
-                description => 'Regexp to split values stored in list element. Usually "\s+" or "[,\s]"',
+                description => 'Regexp to split the value read from ini file. Usually "\s+" or "[,\s]"',
                 warp => {
                     follow => '- backend',
-                    rules  => [ ini_file => { level => 'normal', } ],
+                    rules  => [ IniFile => { level => 'normal', } ],
                 }
             },
 
-            'join_list_value' => {
+            ['join_list_value', 'join_check_list_value'] => {
                 type       => 'leaf',
                 value_type => 'uniline',
                 level      => 'hidden',
-                description => 'string to join values from list element. Usually " " or ", "',
                 warp => {
                     follow => '- backend',
-                    rules  => [ ini_file => { level => 'normal', } ],
+                    rules  => [ IniFile => { level => 'normal', } ],
                 }
             },
 
@@ -301,7 +314,7 @@
                 description => 'Specify how to write a boolean value in config file. Suggested values are '
                     . '"no","yes". ',
                 max_index => 1,
-                cargo => { 
+                cargo => {
                     type => 'leaf',
                     value_type => 'uniline',
                 },
@@ -315,7 +328,7 @@
                 description => "force section to be lowercase",
                 warp => {
                     follow => '- backend',
-                    rules  => [ ini_file => { level => 'normal', } ],
+                    rules  => [ IniFile => { level => 'normal', } ],
                 }
             },
             force_lc_key => {
@@ -326,7 +339,7 @@
                 description => "force key names to be lowercase",
                 warp => {
                     follow => '- backend',
-                    rules  => [ ini_file => { level => 'normal', } ],
+                    rules  => [ IniFile => { level => 'normal', } ],
                 }
             },
             force_lc_value => {
@@ -337,7 +350,7 @@
                 description => "force values to be lowercase",
                 warp => {
                     follow => '- backend',
-                    rules  => [ ini_file => { level => 'normal', } ],
+                    rules  => [ IniFile => { level => 'normal', } ],
                 }
             },
 
@@ -357,13 +370,32 @@
                 type             => 'leaf',
                 value_type       => 'uniline',
                 level            => 'hidden',
-                description      => 'comment starts with this character',
+                description      => 'list of characters that start a comment. When more that one character'
+                .' is used. the first one is used to write back comment. For instance,'
+                .' value "#;" indicate that a comments can start with "#" or ";" and that all comments'
+                .' are written back with "#".',
                 upstream_default => '#',
                 warp             => {
                     follow => '- backend',
-                    rules  => [ ini_file => { level => 'normal', } ],
+                    rules  => [ IniFile => { level => 'normal', } ],
                 }
             },
+
+            'auto_delete' => {
+                type             => 'leaf',
+                value_type       => 'boolean',
+                level            => 'normal',
+                upstream_default => 0,
+                summary          => 'Delete empty configuration file',
+                description      => 'Delete configuration files when no information is left in there.'
+                . ' This may happen when data is removed by user. This is mostly useful when the '
+                . ' configuration of an application is made of several files.',
+            },
+
+        ],
+        description => [
+            join_list_value => 'string to join list values before writing the entry in ini file. Usually " " or ", "',
+            join_check_list_value => 'string to join checked items names before writing the entry in the ini file. Usually " " or ", "',
         ],
 
     ],
@@ -459,8 +491,8 @@
                 type => 'leaf',
                 value_type => 'reference' ,
                 refer_to => '- - element' ,
-                description => 'specify where to insert accepted element. This will'
-                 . ' change the behavior but will help generating more consistent '
+                description => 'specify where to insert accepted element. This does'
+                 . ' not change the behavior and helps generating more consistent '
                  . ' user interfaces'
              }
 
